@@ -50,6 +50,11 @@
 
 #define MAX_URI_IN_DIALOG_LENGTH 50
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 static gboolean
 is_recoverable_error (const GError *error)
 {
@@ -121,7 +126,12 @@ set_message_area_text_and_icon (GtkWidget   *message_area,
 
 	image = gtk_image_new_from_stock (icon_stock_id, GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+	gtk_widget_set_valign (image, GTK_ALIGN_START);
+#else
+	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+#endif
 
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox_content), vbox, TRUE, TRUE, 0);
@@ -132,7 +142,11 @@ set_message_area_text_and_icon (GtkWidget   *message_area,
 	gtk_box_pack_start (GTK_BOX (vbox), primary_label, TRUE, TRUE, 0);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (primary_label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
+#endif
 	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
@@ -147,7 +161,11 @@ set_message_area_text_and_icon (GtkWidget   *message_area,
 		gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
-		gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+		gtk_label_set_xalign (GTK_LABEL (secondary_label), 0.0);
+#else
+		gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
+#endif
 	}
 
 	gtk_widget_show_all (hbox_content);
@@ -509,7 +527,12 @@ create_conversion_error_message_area (const gchar *primary_text,
 
 	image = gtk_image_new_from_stock ("gtk-dialog-error", GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+	gtk_widget_set_valign (image, GTK_ALIGN_START);
+#else
+	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+#endif
   
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox_content), vbox, TRUE, TRUE, 0);
@@ -520,7 +543,11 @@ create_conversion_error_message_area (const gchar *primary_text,
 	gtk_box_pack_start (GTK_BOX (vbox), primary_label, TRUE, TRUE, 0);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (primary_label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
+#endif
 	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
@@ -535,7 +562,11 @@ create_conversion_error_message_area (const gchar *primary_text,
 		gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
-		gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+		gtk_label_set_xalign (GTK_LABEL (secondary_label), 0.0);
+#else
+		gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
+#endif
 	}
 
 	create_combo_box (message_area, vbox);
@@ -774,7 +805,12 @@ pluma_file_already_open_warning_message_area_new (const gchar *uri)
 
 	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+	gtk_widget_set_valign (image, GTK_ALIGN_START);
+#else
+	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+#endif
 
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox_content), vbox, TRUE, TRUE, 0);
@@ -789,7 +825,11 @@ pluma_file_already_open_warning_message_area_new (const gchar *uri)
 	gtk_box_pack_start (GTK_BOX (vbox), primary_label, TRUE, TRUE, 0);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (primary_label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
+#endif
 	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
@@ -804,7 +844,11 @@ pluma_file_already_open_warning_message_area_new (const gchar *uri)
 	gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (secondary_label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
+#endif
 
 	gtk_widget_show_all (hbox_content);
 	set_contents (message_area, hbox_content);
@@ -865,7 +909,12 @@ pluma_externally_modified_saving_error_message_area_new (
 
 	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+	gtk_widget_set_valign (image, GTK_ALIGN_START);
+#else
+	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+#endif
 
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox_content), vbox, TRUE, TRUE, 0);
@@ -884,7 +933,11 @@ pluma_externally_modified_saving_error_message_area_new (
 	gtk_box_pack_start (GTK_BOX (vbox), primary_label, TRUE, TRUE, 0);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (primary_label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
+#endif
 	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
@@ -898,7 +951,11 @@ pluma_externally_modified_saving_error_message_area_new (
 	gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (secondary_label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
+#endif
 
 	gtk_widget_show_all (hbox_content);
 	set_contents (message_area, hbox_content);
@@ -960,7 +1017,12 @@ pluma_no_backup_saving_error_message_area_new (const gchar  *uri,
 
 	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+	gtk_widget_set_valign (image, GTK_ALIGN_START);
+#else
+	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+#endif
 
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox_content), vbox, TRUE, TRUE, 0);
@@ -983,7 +1045,11 @@ pluma_no_backup_saving_error_message_area_new (const gchar  *uri,
 	gtk_box_pack_start (GTK_BOX (vbox), primary_label, TRUE, TRUE, 0);
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (primary_label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
+#endif
 	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
@@ -999,7 +1065,11 @@ pluma_no_backup_saving_error_message_area_new (const gchar  *uri,
 	gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0, 0.5);
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (secondary_label), 0.0);
+#else
+	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
+#endif
 
 	gtk_widget_show_all (hbox_content);
 	set_contents (message_area, hbox_content);
