@@ -49,6 +49,10 @@
 
 #define PLUMA_TAB_KEY "PLUMA_TAB_KEY"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gdk_cursor_unref(cursor) g_object_unref (cursor)
+#endif
+
 struct _PlumaTabPrivate
 {
 	PlumaTabState	        state;
@@ -82,7 +86,11 @@ struct _PlumaTabPrivate
 	gint                    ask_if_externally_modified : 1;
 };
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+G_DEFINE_TYPE(PlumaTab, pluma_tab, GTK_TYPE_BOX)
+#else
 G_DEFINE_TYPE(PlumaTab, pluma_tab, GTK_TYPE_VBOX)
+#endif
 
 enum
 {
@@ -1481,6 +1489,11 @@ pluma_tab_init (PlumaTab *tab)
 	tab->priv->save_flags = 0;
 
 	tab->priv->ask_if_externally_modified = TRUE;
+
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (tab),
+	                                GTK_ORIENTATION_VERTICAL);
+#endif
 	
 	/* Create the scrolled window */
 	sw = gtk_scrolled_window_new (NULL, NULL);
@@ -1859,10 +1872,14 @@ _pluma_tab_get_icon (PlumaTab *tab)
 	theme = gtk_icon_theme_get_for_screen (screen);
 	g_return_val_if_fail (theme != NULL, NULL);
 
+#if GTK_CHECK_VERSION (3, 10, 0)
+	gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, NULL, &icon_size);
+#else
 	gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (GTK_WIDGET (tab)),
 					   GTK_ICON_SIZE_MENU, 
 					   NULL,
 					   &icon_size);
+#endif
 
 	switch (tab->priv->state)
 	{
